bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 4. Aventiure
___________________________________________________ #### Wie er mit den Sahsen <stareit> [6b]
| ### v nahent fremdiu mere in Gunthers lant ### von boten die in verre wurden dar esant ### von vnkunden rechen die in truogen haz ### do si die rede vernamen leit was in werlich daz
###### 139 | ### Die wil ich iv nennen ez was Liudger ### vzer Sahsen lande ein richer furste her ### vnd ovch von Tenemarche der kunich Liudgast ### die brahten in ir reise vil manigen herlichen gast
###### 140 | ### Ir boten komen warn in Gvnthers lant ### die sine viende dar hete gesant ### do vragte man der mære die vnchunden man ### man hiez die boten balde ze houe fur den kunich gan
###### 141 | ### Der kunich si gruozte schone er sprach sit willechomen ### wer iuch her habe gesentet des han ich niht vernomen ### daz svlt ir lazen hoeren sprach der kunich guot ### do vorhten si vil sere den grimmen Gunthers muot
###### 142 | ### Wel ir kunich erlovben daz wir iu mære sagen ### diu wir iu da bringen so sulen wir niht verdagen ### wir nennen iv die herren die vns here habent gesant ### Liudgast vnd Liudger die wellent iuch suochen inz lant
###### 143 | ### Ir habet ir zorn verdient ia horten wir wol daz ### daz iu die herren beide tragent grozen haz ### si wellent heruerten ze Wormz an den Rin ### in hilfet vil der degne des sult ir gewarnet sin
###### 144 | ### Inre zwelf wochen diu reise muoz geschehen ### habet ir iht guoter friunde daz lazet balde schein ### die iu friden helfen die burge vnd iuriu lant ### hie wirt von in verhovwen vil manich helme vnd rant
###### 145 | ### Oder welt ir mit in dingen daz enbietet in dar ### son ritent iu so nahen niht die manigen schar ### der iwer starken viende vof herzenlichiu leit ### davon verderben muozen vil guote ritter gemeit
###### 146 | ### Nv beitet einiv wile ich chvndiu minen muot ### vnz ich mich baz versinne sprach der kunich guot ### han ich guoter iemen die sol ich niht verdagen ### disiu starchen mere sol ich minen friunden clagen
###### 147 | ### Gunthere dem richen leide wart genuoch ### die rede er tovgenliche in sime herze truoch ### er hiez gewinnen Hagnen vnd ander sine man ### vnd bat ovch harte balde ze houe nach Gernoten gan
###### 148 | ### Do chomen dar die besten swaz man der da vant ### er sprach man wil vns suochen her in vnser lant ### mit starchen heruerten daz lat iu wesen leit ### des antwrte Gernot ein riter chuone vnde gemeit
###### 149 | ### Daz wer ot wir mit swerten so sprach Gernot ### da sterbent wan die veigen die lazen ligen tot ### darumbe ich niht vergezzen mach der eren min ### die vnser viende svlen vns willechomen sin
###### 150 | ### Do sprach von Trony Hagne daz dunket mich nih guot ### Liudgast vnd Liudger die tragent vbermvot [7a] ### wir mugen vns niht besenden in so churzen tagen ### so sprach der kuone reche ir sultez Sifride sagen
###### 151 | ### <Die> poten herbergen hiez man in die stat ### swie uient man in were vil schoene ir pflegen bat ### Gunther der riche daz was wol getan ### vnz er eruant an friunden wer in da wolde gestan
###### 152 | ### Dem kunige in sinen sorgen was doch uil leit ### do sach in trurnde ein riter vil gemeit ### der niht mohte wizzen was ime was geschehen ### do bat er im der mære der kunich Gunther veriehen
###### 153 | ### Mich nimet des michel wunder sprach do Sifrit ### wie ir so habet vercheret die froelichen sit ### der ir mit vns nu lange habet alher gepflegen ### des antwrt ime do Gunther der vil cierliche degen
###### 154 | ### la mag ich allen luten die swere niht gesagen ### die ich mvoz toegenliche in mime herzen tragen ### man sol stæten friunden chlagen herze not ### div Sifrides varwe wart do bleich vnde rot
###### 155 | ### Er sprach zuo dem kvnige ich han iv niht verseit ### ich sol iv helfen wenden elliv ivriv leit ### welt ir frivnt suochen der sol ich einer sin ### vnd truowe ez wol volbringen mit eren an daz ende min
###### 156 | ### Nv lon iv got her Sifrit div rede dunchet mich guot ### vnd ob mir nimmer helfe iwer ellen getuot ### ich frov mich doch der mære daz ir mir sit so holt ### lebe ich deheine wile ez wirt wol vmb ivch versolt
###### 157 | ### Ich wil iv hoeren lazen warumbe ich truorich stan ### von boten miner viende ich daz vernomen han ### daz si mich wellent svochen mit heruerte hie ### daz getaten vns noch degne hie ze lande nie
###### 158 | ### Daz lat ivch ahten ringe sprach do Sifrit ### senftet iwer gemvote tuot des ich iv bit ### lat mich iv erwerben eren vnde fruomen ### vnd bitet ivre degne daz si iv ze helfe chumen
###### 159 | ### Swenne iwer starche uiende ze helfe mohten han ### drizech tvsent degne so woldich si bestan ### vnd het ieh miht wan tusent des lat ivch an mich ### do sprach der kunich Gunther daz dien ich immer vmbe dich
###### 160 | ### So heizet mir gewinnen tusent ivr man ### sit daz ich der minen bi mir niht enhan ### niwan zwelf rechen so wer ich iwer lant ### iv sol mit triwen dienen immer Sifrides hant
###### 161 | ### Des sol vns helfen Hagne vnd ovch Ovrtwin ### Danchwart vn– Sindolt die lieben rechen din ### ovch sol da mit riten Volcher der chuene man ### der sol den vanen fuoren daz ich des nieman gan
###### 162 | ### Vnd lat die boten riten heim in ir herren lant ### daz si vns sehen sehiere daz tuo man in bechant ### so daz vnser burge muozen fride han ### do hiez der kunich besenden beide mage vnde man [7b]
###### 163 | ### Die boten Liudigiers ze houe giengen do ### daz si ze lande solden des waren si vil vro ### do bot in riche gabe der kvnich Gunthier guot ### vnd schuof in sin geleite des stuont in hohe der mvot
###### 164 | ### Nu saget sprach do Gunther den starken vienden min ### si mvgent mit ir reise wol deheime sin ### wellen si mich aber suochen her in miniv lant ### miern zerinne miner frivnde in wirt arebeit bechant
###### 165 | ### Den boten riche gabe man do fur truoch ### der het in ze gebene Gunther genvoch ### die wolden niht versprechen die Liudgers man ### do si vrlovp genamen si schieden vrolich dan
###### 166 | ### Do die boten waren ze Tenemarken chomen ### vn der kvnich Liudgast hete daz vernomen ### wie si von Rine chomen als im daz wart geseit ### ir starkez vbermvoten was im werlike leit
###### 167 | ### Si sagten daz si heten vil manigen kuonen man ### ovch sahen si darunder einen reken stan ### der was geheizen Sifrit ein helt uz Niderlant ### ez leidete Liudgaste do er daz mere bevant
###### 168 | ### Do die von Tenemarke ditze horten sagen ### do ilten si der friunde deste me beiagen ### vnz daz er Liudgast siner chuenen man ### zweinzech tvsent degne ze siner reise gewan
###### 169 | ### Do besande sich ovch von Sahsen der chuene Livdger ### vnz si vierzech tusent heten vnd dannoch mer ### mit den si wolden riten in Burgonden lant ### do hete ovch sich hie heime der kvnich Gunther besant
###### 170 | ### mit den sinen magen vnd siner bruoder man ### die si wolden fueren durch urlivge dan ### vnd ovch die Hagnen reken des gie den helden not ### darumbe mvozen degne sider chiesen den tot
###### 171 | ### Si flizzen sich der reise do si wolden dan ### den vanen mvose leiten Volker der chuone man ### also si wolten riten von Wormz an den Rin ### Hagne <von> Tronie der muose scharmeister sin
###### 172 | ### Damite reit ovch Sindolt vnd der kuone Huonolt ### die wol gedienen kvnden daz Gunthers golt ### Danchwart Hagnen bruoder vnd ovch Ortwin ### die mohten wol mnit eren in der herverte sin
###### 173 | ### Her kvnich seit hie heime sprach do Sifrit ### sit daz mir iwer reken wellent volgen mit ### belibet bi den frovwen vnd traget hohen mvot ### ich trov iv wol behuoten beide ere vnde guot
###### 174 | ### Div iuch da wolden svochen ze Wormz an den Rin ### daz wil ich wol behuoten si mugen da heime sin ### wir sulen in geriten so nahen in ir lant ### daz in ir vbermvoten werde ze sorgen bewant
###### 175 | ### Von Rine si durch Hessen mit ir helden riten ### gegen Sahsen lande da wart sit gestriten [8a] ### mit rovbe vnd mit brande wosten si daz lant ### daz ez den fvrsten beiden wart mit arebeit bechant
###### 176 | ### Si chomen vof die marche die knehte zogten dan ### Sifrit der vil starche vragen des began ### wer sol des gesindes vns nu hueten hie ### ia wart den Sahsen geriten schedilicher nie
###### 177 | ### Si sprachen lat die tvmben hueten vof den wegen ### den kuonen Danchwarten der ist ein sneller <degen> ### wir fliesen deste minner von Liudgers man ### lat in vnd ovrtwinen die naht huote han
###### 178 | ### So wil ich selbe riten sprach Sifrit der degen ### vnd wil der warte gen den vienden <pflegen> ### vnz ich rechte eruinde wa die rechen sint ### do wart gewafent schiere der schoenen Siglinden kint
###### 179 | ### Daz volch bevalher Hagnen do er wolde dan ### vnde Gernote dem vil kuone man ### do reiter eine danne in der Sahsen lant ### des wart von im verhowen des tages manich helmbant
###### 180 | ### Do sach er her daz groze daz vf dem velde lac ### daz wider siner helfe mit vngefuoge wac ### des was wol vierzech tusent oder dannoch baz ### Sifrit in hohen mvote sach vil frovlichen daz
###### 181 | ### Do hete sich ovch ein reke gen den vienden dar ### erhaben vof die warte der was ze flize gar ### den sach der herre Sifrit vnd in der kuone man ### ieweder do des andern mit nide huoten began
###### 182 | ### Ich sag iv wer der were der der warte <pflach> ### ein liehter schilt von golde im vor der hende lac ### ez was der kvnich Livdgast der huote siner schar ### dirre gast vil edele spranchte herlichen dar
###### 183 | ### Nv het ovch in her Livdgast vientlichen erkorn ### div ros si namen beidiu cen siten mit den sporn ### si neigten vf die schilde die schefte mit ir chraft ### des wart der kunich riche mit grozen sorgen behaft
###### 184 | ### Diu ros nach sachen truogen diu richen kuniges kint ### beide fur ein ander sam si wete ein wint ### mit zovmen wart gewendet vil riterlichen dan ### mit swerten ez versuohten die zwene grimme man
###### 185 | ### Do sluoch der herre Sifrit daz al daz velt erdoz ### do stovp vz dem helme sam von brenden groz ### die viwer rote vanchen von des heldes hant ### ir ietweder den sinen an dem anderen vant
###### 186 | ### Ovch sluog im her Liudgast vil manigen grimmen slach ### ir ieweders ellen vf schilden vaste lac ### do heten daz gehuotet wol drizech siner man ### e daz im die chomen den sich doch Sifrit gewan
###### 187 | ### mit drin starchen wnden die er dem kunige sluoc ### durch eine wize brunne diu was guot genuoc ### daz swert an sinen eken braht vz wunden bluot ### des muose der kunige Liudgast haben truorigen muot [8b]
###### 188 | ### Er bat sich leben lazen vnd bot im siniv lant ### vnde sagte im daz er were Liudgast genant ### do komen sine rechen die heten wol gesehen ### was da von in beiden vf der warte was geschehen
###### 189 | ### Er wolt in fueren dannen do wart er an gerant ### von drizech sinen mannen do werte des heldes hant ### sinen richen gisel mit vngefuegen slegen ### sit tet schaden mere der cierliche degen
###### 190 | ### Die drizech er ze tode vil werlichen sluoc ### er liez in leben einen balde er reit genuoc ### vnd sagte hin diu mere was hie was geschehen ### ovch mohte mans die warheit an sime roten helmen sehen
###### 191 | ### Den von Tenemarke was vil grimme leit ### ir herre was gevangen do in daz was geseit ### man sagte ez sinen bruoder toben er began ### von vngefuegem zorne wan im leide was getan
###### 192 | ### Livdgast der reche was gefueret dan ### von Sifrides gewalte zvo Gunthers man ### er bevalch in Hagnen do in daz wart geseit ### daz er der kunich were do was in mazlichen leit
###### 193 | ### Man hiez den Burgonden ir vanen binden an ### wol vof sprach Sifrit hie wirt mere getan ### ê sich der tac verende sol ich haben den lip ### daz gemvot in Sahsen vil manich wætliche wip
###### 194 | ### Ir helde von dem Rine ir svlt min nemen war ### ich chan iuch wol geleiten in Liudgers schar ### so sehet ir helme howen von guoter helde hant ### ê daz wir wider wenden iv wirdet sorge bechant
###### 195 | ### Ze rossen gahte do Gernot vnde die sine man ### den vanen zvchte balde der kvone spilman ### Volcher der herre do reit er vor der schar ### do was ovch daz gesinde ze strite erlichen gar
###### 196 | ### Si fuorten doch niht mere niwan tvsent man ### darvber zwelf reken stieben do began ### diu molte von den strazen si riten vber lant ### do sach man von in schinen vil manigen herlichen rant
###### 197 | ### Do waren ovch die Sahsen mit ir schar chomen ### mit swerten wol gewahsen daz han ich sit vernomen ### div swert die sniten sere den helden an der hant ### do wolden si den gesten weren burge vnd lant
###### 198 | ### Der herren scharmeister daz volc do fuorten dan ### do was ovch Sifrit komen mit den sinen man ### die er mie in brahte vzer Niderlant ### des tages wart in sturme vil manich bluotigiu hant
###### 199 | ### Sindolt vnd Huonolt vnd ovch Gernot ### die sluogen in dem strite vil manigen helt tot ### ê si rehte erfvnden wie chuene was ir lip ### daz mvose sid beweinen vil manich wætlichez wip
###### 200 | ### Volker vnd Hagne vnd ovch Ortwin ### laschten in dem bluote vil maniges helmes schin [9a] ### mit fliezendem bluote die sturm kuene man ### da wart von Danchwarte vil michel wunder getan
###### 201 | ### Die von Tenemarche versvohten wol ir hant ### do horte man von hurte erdiezen manigen rant ### vnd ovch von scharphen swerten der man da uil gesluoch ### die stritkuonen Sahsen taten schaden da genuoch
###### 202 | ### Do die von Burgonden drvngen in den strit ### von in wart verhowen vil manich wnde wit ### do sach man vber satele vliezen daz bluot ### svs wrben nach den eren die helde chuone vnde guot
###### 203 | ### Man horte da liute erhellen den helden an der hant ### diu vil scharpfen wafen do die von Niderlant ### drvngen nach ir herren in die herten schar ### si chomen degenliche mit samt Sifride dar
###### 204 | ### Volgen der von Rine nieman man im sach ### man mohte kiesen fliezen den bluotigen bach ### durch die liehten helme von Sifrides hant ### den herren Liudgern er nv vor sinen hergesellen vant
###### 205 | ### Dri widerchere heter nu genomen ### durch daz her anz ende nu was Hagen chomen ### der half im wol ervollen in sturme sinen mvot ### des muose da ersterben vor im vil manich riter guot
###### 206 | ### Do der starke Liudger Sifriden vant ### vnd daz er alse hohe truoch an siner hant ### den guoten Balmungen vnd ir so manigen sluoch ### des wart der herre zornich vnde grimmich genuoch
###### 207 | ### Do wart michel dringen vnd grozer swerte chlanch ### da ir ingesinde zvo ein ander dranch ### do versuohten si die rechen beide dester baz ### die schar begunden wichen sic huop da grozlicher haz
###### 208 | ### Dem vogte von den Sahsen was daz wol geseit ### sin bruoder was gevangen daz vas im harte leit ### wol wesser daz er tæte daz Siglinde kint ### man ceh es Gernoten wol ervant er ez sint
###### 209 | ### Die slege Liudgers die waren also starch ### daz im vnderm satle struhte daz marc ### do sich daz ros erholte der kuene Sifrit ### der gewan in dem sturme einen freislichen sit
###### 210 | ### Des half im Hagne vnd ovch Gernot ### Danchwart vnd Volker des lag ir uil da tot ### Sindolt vnd Huonolt vnd oertwin der degen ### die chvnden in dem strite cem tode manigen nider legen
###### 211 | ### In sturme vngescheiden waren die fvrsten her ### do sach man vber helme fliegen manigen ger ### durch die liehten schilde von der helde hant ### man sach da uar nach bluote vil manigen herlichen rant
###### 212 | ### In dem starken stvrme erbeizte manich man ### nider von den rossen an ander liefens an ### Sifrit der kuene vnd ovch Livdger ### man sach da sefte vliegen vnd vil manigen scarfen ger [9b]
###### 213 | ### Do flovch daz schiltgespenge von Sifrides hant ### den sic gedaht erwerben der helt von Niderlant ### an den kuenen Sahsen der man wundersach ### hey waz liehter ringe der kuene Danchwart zebrach
###### 214 | ### Do het der herre Livdger vf eime schilte erkant ### gemalt eine krone vor Sifrides hant ### wol wesser daz ez were der kreftige man ### der helt zuo sinem frivnden luote ruofen began
###### 215 | ### Gelovbet iuch des strites alle mine man ### svn den Sigmundes ich hie geselhen han ### Sifriden den starken han ich hie bekant ### in hat der ubel tivfel cen Sahsen gesant
###### 216 | ### Die vanc hiez er lazen in deme sturme nider ### frides er do gerte des werte man in sider ### doch muoser werden sigel in Gunthers lant ### daz het an im betwngen div Sifrides hant
###### 217 | ### Mit gemeinem rate so liezen si den strit ### durkel vil der helme vnd der schilte wit ### si leiten von den handen swaz so man der vant ### die truogen bluotes varwe von der Burgonden lant
###### 218 | ### Si viengen swem si wolten des heten si gewalt ### Gernot vnd Hagne die reken vil balt ### die wnden hiezen barn si fuorten mit in dan ### geuangen zuo dem Rine funfhundert wetlicher man
###### 219 | ### Die siglosen reken ze Tenemarken riten ### do heten ovch die Sahsen so hohe niht gestriten ### daz man in lobes iæhen daz was den helden leit ### do wurden ovch die veigen von friunden sere gecleit
###### 220 | ### Si hiezen ir gewefen sovmen an den Rin ### ez here wol geworben mit den henden sin ### Sifrit der reke der hetez guot getan ### des im iehen muosen alle Gunthers man
###### 221 | ### Gegen Wurmes sande der herre Gernot ### heim ze <sinem> lande den frivnden er enbot ### wie gelungen were im vnd sinem man ### ez heten die vil kuonen wol nach eren getan
###### 222 | ### Die garzune liefen von den ez wart geseit ### da freuten sieh von liebe die e heten leit ### dirre lieben mere div in da waren komen ### da wart von edelen frovwen michel fragen vernomen
###### 223 | ### wie gelungen were des richen kvniges man ### man hiez der boten einen fur Chriemhilde gan ### daz geschach vil tovgen ian torstez vber lut ### wan si hete darunder ein liebez herzen truot
###### 224 | ### Do si den boten komende zir kemenate sach ### Chriemhilt div schoene vil guetlichen sprach ### nu sag an liebiv mere ia gib ich dir min golt ### tuostuz an liegen ich wil dir immer wesen holt
###### 225 | ### Wie schiet vz dem strite min bruoder Gernot ### vnd ander mine friunde ist vns ieman tot [10a] ### oder wer tet daz beste daz solt du mir sagen ### do sprach der bote schiere wir heten ninder einen zagen
###### 226 | ### Ze ernste vnd ze strite reit nieman also wol ### vil ediliv kvniginne sit ich ivz sagen sol ### so der gast vil edele vzer Niderlant ### da worhte michel wunder des kuenen Sifrides hant
###### 227 | ### Swaz die reken alle in strite han getan ### Danchwart vnd Hagne vnd anders kvniges man ### swaz si na ern striten das was gar ein wint ### wan aleine Sifrit des kvnich Sigmundes kint
###### 228 | ### Si fruomten in dem sturme der helde vil derslagen ### doch moht iu dizze wunder nieman wol gesagen ### waz da worhte Sifrit suuenner ze strite reit ### den frovwen an ir magen tet er div grozlichen leit
###### 229 | ### Ovch mvoste da beliben vil maniger frovwen truot ### sin slege man horte vf helmen also lut ### daz si von wunden brahten daz fliezende bluot ### er ist an allen dingen ein riter kvone vn– gvot
###### 230 | ### Swaz da hat begangen von Mece oertwin ### swaz er ir mohte erlangen mit dem swerte sin ### die mvozen wnt beliben oder meistec tot ### da tet iwer bruoder die aller grozisten not
###### 231 | ### div immer in den sturmen chvnde sin geschehen ### man mvoz der warheite dem vz derwelten iehen ### die stolzen Burgonden habent so geuarn ### daz si vor allen schanden sich kunnen wol bewarn
###### 232 | ### Man sach da von ir handen vil manigen satel bloz ### da von liehten swerten daz velt so lv^te erdoz ### die reken von dem Rine die habent so geriten ### daz ez ir vienden wære bezer vermiten
###### 233 | ### Die kuenen Troniere die fruomten groziv leit ### do mit volkes kreften daz her zesamne reit ### da frumte manigen toten des chuenen Hagnen hant ### des vil ze <sagene> were her in Bvrgonden lant
###### 234 | ### Sindolt vnd Huonolt die Gernotes man ### vnd Ruomolt der kuone die hant so vil getan ### daz ez Liudgere mag immer wesen leit ### daz er den iwren magen ce Rine widerseit
###### 235 | ### Strit den aller hohsten der inder da geschach ### ze iungest vnd zem ersten den ieman da gesach ### den tet vil degenlichen div Sifrides hant ### er bringet rike gisle in Gvnthers lant
###### 236 | ### Die twanch mit sinen ellen der wætlike man ### des ovch der kvnich Liudgast mvoz den schaden han ### vnd ovch von Sahsen landen sin bruoder Liudger ### nu hoert miniv mære edel kvniginne her
###### 237 | ### Si hat gevangen beide div Sifrides hant ### nie so manigen gysel man braht in dize lant ### so von sinen schvlden nv kvmt an den Rin ### ir chvnden disiv mere nimmer lieber gesin [10b]
###### 238 | ### Man bringet der gesvnden fvnf hvndert oder baz ### vnd der verchvnden wizet frovwe daz ### wol ahzech rote bare her in vnser lant ### die meist hat verhowen des <kuenen> Sifrides hant
###### 239 | ### Die durch vbermvote widerseiten an den Rin ### die muozen nu gevangen die Gvnthers sin ### die bringet man mit vrovden her in dize lant ### do erbluete ir liehtiv varwe do si div mere rehte bevant
###### 240 | ### Ir schonez antluze daz wart rosen rot ### do mit liebe was gescheiden vz so grozer not ### Sifrit der iunge der wætliche man ### si vreute ovch sich ir frivnde daz was von schulden getan
###### 241 | ### Do sprach div minnechliche dv hast mir wol geseit ### dv solt darvmbe haben ze miete richiv chleit ### cehen march von golde die heize ich dir nu tragen ### des mach man solhiv mære richen frovwen gerne sagen
###### 242 | ### Man gap ime sine miete dar golt vnd ovch daz cleit ### do gie an div venster vil manich schoniv meit ### si warten vf die straze riten man do vant ### vil der hoh gemvoten in der Burgunden lant
###### 243 | ### Da chomen die gesvnden die wunden taten sam ### si mohten gruozen hoeren von frivnden ane scham ### der wirt gen sinen gesten vil frolichen reit ### mit vrovden was verendet sin grozlichez leit
###### 244 | ### Do enphie er wol die sine die fremden tet er sam ### wan dem riken kvnige anders niht enzam ### wan danken guetliche den die im waren chomen ### daz si den sic nach eren in stvrme heten genomen
###### 245 | ### Gvnther bat im mære von sinen frivnden sagen ### wer im an der reise ze tode waren erslagen ### do het er verlorn niemen niwan sechzech man ### verchlagen man die mvese so sit vil helde sint getan
###### 246 | ### Die gesvnden brahten zerhowen manigen rant ### von helme vil verscroten in Gvnthers lant ### daz volk erbeizte nider fur des kvniges sal ### ze lieben antfange man horte grozlichen schal
###### 247 | ### Do hiez man herbergen die rechten in die stat ### der kvnich siner geste vil schone pflegen bat ### er hiez der wunden huoten vnd schafen guot gemach ### wol man sine tvgende an sinen vienden sach
###### 248 | ### Er sprach ze Liudegaste nu sit mir willechomen ### ich han von iwren schvlden schaden vil genomen ### der wirt mir nv vergolten ob ich geluche han ### got lone minen friunden si habent liebe mir getan
###### 249 | ### Ir mvget in gerne danchen sprach do Livdger ### also hoher gysel gewan nie chvnich mer ### vmbe schone huote wir geben michel guot ### daz ir genedichlichen an iwren vienden tuot
###### 250 | ### Ich wil iv beide lazen sprach er ledech gen ### daz mine viende hie bi mir besten [11a] ### des wil ich haben purgen daz si miniv lant ### iht rvmen ane hulde des bot do Liudger die hant
###### 251 | ### Man brahte si ze ruwe vnd schuof in ir gemach ### den wunden man gebettet vil guotlichen sach ### man schanchte den gesvnden met vnd guoten win ### do chvnde daz gesinde nimmer frolicher sin
###### 252 | ### Ir zerhowen schilde behalten man do truoch ### vil bluotiger setle der was da genvoch ### die hiez man verbergen daz weinten niht diu wip ### da kom her vil muede maniges guoten ritters lip
###### 253 | ### Der kvnich pflac siner geste vil guotlichen wol ### der fremden vnd der kvnden diu lant waren vol ### er bat der ser wunden vil guotlichen phlegen ### do was ir vbermueten vil harte ringe gelegen
###### 254 | ### Die erzenie chvnden den bot man richen solt ### silber ane wage darzuo daz liehte golt ### daz sich die helde nerten nach des strites not ### daz zuo der kvnich den gesten gabe grozlichen bot
###### 255 | ### Die wider heim ze hûse heten reise mvot ### die bat man noch beliben so man frivnden tuot ### der kvnich gie ze rate wie er lonte sinen man ### si heten sinen willen nach grozen eren getan
###### 256 | ### Do sprach der herre Gernot man sol si riten lan ### vber sehs wochen si in daz chunt getan ### daz si chomen widere zeiner hohgecit ### so ist maniger geheilet der noch wunder lit
###### 257 | ### Do gerte ovch vrlovbes Sifrit von Niderlant ### do der kvnich Gunther den willen sin eruant ### er bat im minnechlichen noch bi im bestan ### niwan durch sin swester son werez niht getan
###### 258 | ### Darzuo was er ze riche daz er iht nemen solt ### er hetez wol verdienet der kunich was im holt ### sam waren sine magen die heten daz gesehen ### waz von sinen handen in dem strite was geschehen
###### 259 | ### Dvrch der schuonen willen gedaht er noch bestan ### ob er si sehen mohte sit wart ez getan ### wol nach sinen willen wart im div maget bechant ### sit reiter froliche in Sigemvndes lant
###### 260 | ### Der wirt hiez ce allen ziten riterschefte pflegen ### daz tet vil willechlichen do manich iunger degen ### die wile hiez er sideln vor Wormz an den sant ### den die im komen solden in der Burgonden lant
###### 261 | ### In den selben ziten do si nu solden chomen ### do het div schone <Chriemhilt> div mære wol vernomen ### er wolde hohgecite durch liebe friunde han ### do wart vil michel flizen von schonen frowen getan
###### 262 | ### mit wete vnd mit gebene daz si da solden tragen ### vote div vil riche div mere horte sagen ### von den stolzen reken die da solden chomen ### do wart vz der valde vil richer chleider genomen [11b]
###### 263 | ### Dvrch ir kinde liebe hiez si bireiten chleit ### da mite wart gezieret vil frovwen vn– meit ### vnd uil der iungen rechen vz Bvrgonden lant ### si hiez ovch vil der fremden bruoven herlich gewant

<<< Übersicht <<< vorige Seite nächste Seite >>>